[![Software License](https://img.shields.io/badge/license-AGPL--3.0-green.svg?style=for-the-badge)](../LICENSE)
[![Documentation](https://img.shields.io/badge/pydoc-reference-blue?style=for-the-badge)](https://omniversion.github.io/omniversion/python/omniversion)

<!--suppress HtmlDeprecatedAttribute -->
<div align="center">
    <img src="../docs/assets/python.png" width="128" height="128" alt="omniversion logo" />
    <h2 align="center">omniversion python integration</h2>
    <br />
</div>
